==> dxcr-vue-cesium-0.0.1.tgz: package/lib/tool/drawHandlerPolygon/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.1.6
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2020, zouyaoji <370681295@qq.com>
 */
import mixinDraw from '../../mixins/tool/mixinDraw';
import { makeMaterial } from '../../utils/cesiumHelpers';
import { clone } from '../../utils/util';

//
var script = {
  name: 'vc-handler-draw-polygon',
  mixins: [mixinDraw],
  data: function data() {
    return {
      drawType: 'polygonDrawing',
      drawing: false,
      polylines: [],
      nowaiting: true
    };
  },
  props: {
    depthTest: {
      type: Boolean,
      default: true
    },
    perPositionHeight: {
      type: Boolean,
      default: true
    },
    polylineMaterial: {
      type: Object,
      default: function _default() {
        return {
          fabric: {
            type: 'Color',
            uniforms: {
              color: '#51ff00'
            }
          }
        };
      }
    },
    polylineWidth: {
      type: Number,
      default: 2
    },
    polygonMaterial: {
      type: Object,
      default: function _default() {
        return {
          fabric: {
            type: 'Color',
            uniforms: {
              color: 'rgba(255,165,0,0.25)'
            }
          }
        };
      }
    },
    clampToGround: {
      type: Boolean,
      default: false
    }
  },
  methods: {
    makeEllipsoidSurfaceAppearance: function makeEllipsoidSurfaceAppearance(val) {
      return new Cesium.EllipsoidSurfaceAppearance({
        material: makeMaterial.call(this, val),
        renderState: {
          cull: {
            enabled: false
          }
        }
      });
    },
    makePolylineMaterialAppearance: function makePolylineMaterialAppearance(val) {
      return new Cesium.PolylineMaterialAppearance({
        material: makeMaterial.call(this, val)
      });
    },
    clone: clone
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('i', {
    class: _vm.$options.name,
    staticStyle: {
      "display": "none !important"
    }
  }, [_c('vc-collection-primitive', {
    attrs: {
      "show": _vm.show
    }
  }, [!_vm.clampToGround ? _c('vc-collection-primitive', {
    ref: "polygonCollection"
  }, [_vm._l(_vm.polylines, function (polyline, index) {
    return [polyline.positions.length > 2 ? _c('vc-primitive', {
      key: index,
      attrs: {
        "appearance": _vm.makeEllipsoidSurfaceAppearance(_vm.polygonMaterial),
        "asynchronous": false
      }
    }, [_c('vc-instance-geometry', [_c('vc-geometry-polygon', {
      attrs: {
        "perPositionHeight": true,
        "polygonHierarchy": _vm.clone(polyline.positions, true)
      }
    })], 1)], 1) : _vm._e()];
  })], 2) : _c('vc-collection-primitive', {
    ref: "groundPolygonCollection"
  }, [_vm._l(_vm.polylines, function (polyline, index) {
    return [polyline.positions.length > 2 ? _c('vc-primitive-ground', {
      key: index,
      attrs: {
        "appearance": _vm.makeEllipsoidSurfaceAppearance(_vm.polygonMaterial),
        "asynchronous": false
      }
    }, [_c('vc-instance-geometry', [_c('vc-geometry-polygon', {
      attrs: {
        "perPositionHeight": false,
        "polygonHierarchy": _vm.clone(polyline.positions, true)
      }
    })], 1)], 1) : _vm._e()];
  })], 2), _vm._v(" "), _vm.clampToGround ? _c('vc-collection-primitive', {
    ref: "groundPolylineCollection"
  }, [_vm._l(_vm.polylines, function (polyline, index) {
    return [polyline.positions.length > 1 ? _c('vc-primitive-polyline-ground', {
      key: index,
      attrs: {
        "appearance": _vm.makePolylineMaterialAppearance(_vm.polylineMaterial),
        "asynchronous": false
      }
    }, [_c('vc-instance-geometry', [_c('vc-geometry-polyline-ground', {
      attrs: {
        "positions": polyline.positions,
        "width": _vm.polylineWidth,
        "loop": ""
      }
    })], 1)], 1) : _vm._e()];
  })], 2) : _c('vc-collection-primitive-polyline', {
    ref: "polylineCollection"
  }, _vm._l(_vm.polylines, function (polyline, index) {
    return _c('vc-primitive-polyline', {
      key: index,
      attrs: {
        "material": _vm.polylineMaterial,
        "positions": polyline.positions,
        "width": _vm.polylineWidth,
        "loop": ""
      }
    });
  }), 1), _vm._v(" "), _c('vc-collection-primitive-point', {
    ref: "pointCollection"
  }, [_vm._l(_vm.polylines, function (polyline, index) {
    return [_vm._l(polyline.positions, function (position, subIndex) {
      return [_c('vc-primitive-point', {
        key: 'point' + index + 'position' + subIndex,
        attrs: {
          "color": _vm.pointColor,
          "pixelSize": _vm.pointPixelSize,
          "position": position
        }
      })];
    })];
  })], 2)], 1)], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "VcDrawHandlerPolygon.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var VcDrawHandlerPolygon = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(VcDrawHandlerPolygon.name, VcDrawHandlerPolygon);
}

export default plugin;
export { VcDrawHandlerPolygon, plugin as install };

==> dxcr-vue-cesium-0.0.2.tgz: package/lib/tool/drawHandlerPolygon/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.2.0
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2021, zouyaoji <370681295@qq.com>
 */
import mixinDraw from '../../mixins/tool/mixinDraw';
import { makeMaterial } from '../../utils/cesiumHelpers';
import { clone } from '../../utils/util';
import * as PrimitiveCollection from '../../primitiveCollection';
import * as GroundPrimitive from '../../primitive/ground';
import * as GeometryInstance from '../../geometryInstance';
import * as PolygonGeometry from '../../geometryInstance/polygon';
import * as Primitive from '../../primitive';
import * as GroundPolylinePrimitive from '../../primitive/groundPolyline';
import * as GroundPolylineGeometry from '../../geometryInstance/groundPolyline';
import * as PolylineCollection from '../../primitiveCollection/polylineCollection';
import * as Polyline from '../../primitive/polyline';
import * as PointPrimitiveCollection from '../../primitiveCollection/pointCollection';
import * as PointPrimitive from '../../primitive/point';
import * as VcHTMLOverlay from '../../extend/htmlOverlay';

//
var script = {
  name: 'vc-handler-draw-polygon',
  mixins: [mixinDraw],
  data: function data() {
    return {
      drawType: 'polygonDrawing'
    };
  },
  props: {
    depthTest: {
      type: Boolean,
      default: true
    },
    perPositionHeight: {
      type: Boolean,
      default: true
    },
    polylineMaterial: {
      type: Object,
      default: function _default() {
        return {
          fabric: {
            type: 'Color',
            uniforms: {
              color: '#51ff00'
            }
          }
        };
      }
    },
    polylineWidth: {
      type: Number,
      default: 2
    },
    polygonMaterial: {
      type: Object,
      default: function _default() {
        return {
          fabric: {
            type: 'Color',
            uniforms: {
              color: 'rgba(255,165,0,0.25)'
            }
          }
        };
      }
    },
    clampToGround: {
      type: Boolean,
      default: false
    }
  },
  computed: {
    primitivePolylines: function primitivePolylines() {
      var _this = this;

      var polylines = [];
      this.polylines.forEach(function (item, index) {
        var polyline = {
          material: _this.polylineMaterial,
          positions: item.positions,
          width: _this.polylineWidth,
          loop: true,
          polylineIndex: index
        };
        polylines.push(polyline);
      });
      return polylines;
    }
  },
  methods: {
    makeEllipsoidSurfaceAppearance: function makeEllipsoidSurfaceAppearance(val) {
      return new Cesium.EllipsoidSurfaceAppearance({
        material: makeMaterial.call(this, val),
        renderState: {
          cull: {
            enabled: false
          }
        }
      });
    },
    makePolylineMaterialAppearance: function makePolylineMaterialAppearance(val) {
      return new Cesium.PolylineMaterialAppearance({
        material: makeMaterial.call(this, val)
      });
    },
    clone: clone
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('i', {
    class: _vm.$options.name
  }, [_c('vc-collection-primitive', {
    attrs: {
      "show": _vm.show
    }
  }, [!_vm.clampToGround ? _c('vc-collection-primitive', {
    ref: "polygonCollection"
  }, [_vm._l(_vm.polylines, function (polyline, index) {
    return [polyline.positions.length > 2 ? _c('vc-primitive', {
      key: index,
      attrs: {
        "appearance": _vm.makeEllipsoidSurfaceAppearance(_vm.polygonMaterial),
        "asynchronous": false
      }
    }, [_c('vc-instance-geometry', [_c('vc-geometry-polygon', {
      attrs: {
        "perPositionHeight": true,
        "polygonHierarchy": _vm.clone(polyline.positions, true)
      }
    })], 1)], 1) : _vm._e()];
  })], 2) : _c('vc-collection-primitive', {
    ref: "groundPolygonCollection"
  }, [_vm._l(_vm.polylines, function (polyline, index) {
    return [polyline.positions.length > 2 ? _c('vc-primitive-ground', {
      key: index,
      attrs: {
        "appearance": _vm.makeEllipsoidSurfaceAppearance(_vm.polygonMaterial),
        "asynchronous": false
      }
    }, [_c('vc-instance-geometry', [_c('vc-geometry-polygon', {
      attrs: {
        "perPositionHeight": false,
        "polygonHierarchy": _vm.clone(polyline.positions, true)
      }
    })], 1)], 1) : _vm._e()];
  })], 2), _vm._v(" "), _vm.clampToGround ? _c('vc-collection-primitive', {
    ref: "groundPolylineCollection"
  }, [_vm._l(_vm.polylines, function (polyline, index) {
    return [polyline.positions.length > 1 ? _c('vc-primitive-polyline-ground', {
      key: index,
      attrs: {
        "appearance": _vm.makePolylineMaterialAppearance(_vm.polylineMaterial),
        "asynchronous": false
      }
    }, [_c('vc-instance-geometry', [_c('vc-geometry-polyline-ground', {
      attrs: {
        "positions": polyline.positions,
        "width": _vm.polylineWidth,
        "loop": ""
      }
    })], 1)], 1) : _vm._e()];
  })], 2) : _c('vc-collection-primitive-polyline', {
    ref: "polylineCollection",
    attrs: {
      "polylines": _vm.primitivePolylines
    }
  }), _vm._v(" "), _c('vc-collection-primitive-point', {
    ref: "pointCollection",
    attrs: {
      "points": _vm.points
    },
    on: {
      "mouseover": _vm.pointMouseOver,
      "mouseout": _vm.pointMouseOut
    }
  })], 1), _vm._v(" "), _vm.showToolbar ? _c('vc-overlay-html', {
    attrs: {
      "position": _vm.toolbarPosition
    }
  }, [_c('button', {
    staticClass: "vc-btn",
    attrs: {
      "title": _vm.$vc.lang.draw.editingMove,
      "type": "button"
    },
    on: {
      "click": function click($event) {
        return _vm.onEditClick('move');
      }
    }
  }, [_c('vc-icon-svg', {
    attrs: {
      "name": "icon-move"
    }
  })], 1), _vm._v(" "), _c('button', {
    staticClass: "vc-btn",
    attrs: {
      "title": _vm.$vc.lang.draw.editingInsert,
      "type": "button"
    },
    on: {
      "click": function click($event) {
        return _vm.onEditClick('insert');
      }
    }
  }, [_c('vc-icon-svg', {
    attrs: {
      "name": "icon-add"
    }
  })], 1), _vm._v(" "), _c('button', {
    staticClass: "vc-btn",
    attrs: {
      "title": _vm.$vc.lang.draw.editingDelete,
      "type": "button"
    },
    on: {
      "click": function click($event) {
        return _vm.onEditClick('delete');
      }
    }
  }, [_c('vc-icon-svg', {
    attrs: {
      "name": "icon-delete"
    }
  })], 1)]) : _vm._e(), _vm._v(" "), _vm.showTooltip && _vm.showDrawTip ? _c('vc-overlay-html', {
    attrs: {
      "position": _vm.tooltipPosition,
      "pixelOffset": [32, 32]
    }
  }, [_c('div', {
    staticClass: "vc-html-bubble"
  }, [_vm._v(_vm._s(_vm.tooltip))])]) : _vm._e()], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "VcDrawHandlerPolygon.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var VcDrawHandlerPolygon = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.use(PrimitiveCollection);
  Vue.use(GroundPrimitive);
  Vue.use(GeometryInstance);
  Vue.use(PolygonGeometry);
  Vue.use(Primitive);
  Vue.use(GroundPolylinePrimitive);
  Vue.use(GroundPolylineGeometry);
  Vue.use(PolylineCollection);
  Vue.use(Polyline);
  Vue.use(PointPrimitiveCollection);
  Vue.use(PointPrimitive);
  Vue.use(VcHTMLOverlay);
  Vue.component(VcDrawHandlerPolygon.name, VcDrawHandlerPolygon);
}

export default plugin;
export { VcDrawHandlerPolygon, plugin as install };
